function out=nlsystem1( in , nl_id )
% A collection of nonlinear models
% OUT= NLSYSTEM1( IN , nl_id)
%  INPUT
%     in - input signal (must be a column vector)
%     nl_id - the number of a difference equation to be used (see below)
%  OUTPUT
%    out - output signal
%
%  The possible values for N
%  nl_id=0
%     y[n]=5x[n]-2x[n-1]+x[n-2]+3x[n]^2-x[n-1]^2+0.5x[n-2]^2  
%  nl_id=1
%     y[n]=5x[n]-2x[n-1]+x[n-2]+3x[n]^2-x[n-1]^2+0.5x[n-2]^2-
%          -2x[n]x[n-1]-1x[n]x[n-2]-1.5x[n-1]x[n-2]
%  nl_id=2
%     y[n]=5x[n]-2x[n-1]+x[n-2]+3x[n]^2-x[n-1]^2+0.5x[n-2]^2-
%          -2x[n]x[n-1]-1x[n]x[-2]-1.5x[n-1]x[n-2]-
%          -3*x[n]^3+4*x[n]^2*x[n-2]-1.5*x[n]*x[n-1]*x[n-2]


%  Rev. 1.0      Oct. 24, 2002  Dmitriy Shutin <dshutin@inw.tugraz.at>

%input test
if nargin<1
    out=[];
    return
end
[dx,dy]=size(in);
in=in(:);
if nargin<2
    N=0;
end
tap=4;
in=[zeros(tap-1,1); in];
for l=1:length(in)-tap+1
    z=in(l+tap-1:-1:l);
    % Difference equation implementation
    switch nl_id
        case 0
        %y[n]=5x[n]-2x[n-1]+x[n-2]+3x[n]^2-x[n-1]^2+0.5x[n-2]^2
            % linear part
            out(l,1)=5*z(1)-2*z(2)+1*z(3);
            % quadratic terms
            out(l,1)=out(l,1)+3*z(1)^2-1*z(2)^2+0.5*z(3)^2;
        case 1
        %y[n]=5x[n]-2x[n-1]+x[n-2]+3x[n]^2-x[n-1]^2+
        %     +0.5x[n-2]^2-2x[n]x[n-1]-1x[n]x[n-2]-1.5x[n-1]x[n-2]
            % linear part
            out(l,1)=5*z(1)-2*z(2)+1*z(3);
            % quadratic terms
            out(l,1)=out(l,1)+3*z(1)^2-1*z(2)^2+0.5*z(3)^2;
            % mixed terms
            out(l,1)=out(l,1)-2*z(1)*z(2)-1*z(1)*z(3)-1.5*z(2)*z(3); 
        case 2
        % y[n]=5x[n]-2x[n-1]+x[n-2]+3x[n]^2-x[n-1]^2+
        %      +0.5x[n-2]^2-2x[n]x[n-1]-1x[n]x[n-2]-1.5x[n-1]x[n-2]-
        %      -3*x[n]^3+4*x[n]^2*x[n-2]-1.5*x[n]*x[n-1]*x[n-2]
            % linear part
            out(l,1)=5*z(1)-2*z(2)+1*z(3);
            % quadratic terms
            out(l,1)=out(l,1)+3*z(1)^2-1*z(2)^2+0.5*z(3)^2;
            % mixed terms
            out(l,1)=out(l,1)-2*z(1)*z(2)-1*z(1)*z(3)-1.5*z(2)*z(3); 
            % cubic terms
            out(l,1)=out(l,1)-3*z(1)^3+4*z(1)^2*z(3)-1.5*z(1)*z(2)*z(3); 
        otherwise
            error('Second parameter is not specified properly! See help')
    end
    
end
out=buffer(out,dx);   
    
    
