function visbispec3(bispec, Sigma, f_x1,f_x2)
% VISBISPEC3  Visualization of the bispectrum ( and bicoherence)
%  visbispec3(bispec,f_x1,f_x2, Sigma)
%  INPUT 
%    bispec - third order cumulant
%     Sigma - variance of the signal (needed for color calibration)
%      f_x1 - frequency axes (optional) 
%      f_x2  
%    


%  Rev 1.1    Jan. 7, 2009,  Dmitriy Shutin  <dshutin@tugraz.at>


if nargin<1
    error('Not enough input arguments');
end

b_int=interpn(abs(bispec),2,'cubic'); % interpolation for smoother results

if nargin<3
    [n,m]=size(bispec);
    f_x1=linspace(-1,1,size(b_int,1))';
    f_x2=linspace(-1,1,size(b_int,2))';
else
    f_x1=linspace(min(f_x1),max(f_x1),size(b_int,1));
    f_x2=linspace(min(f_x2),max(f_x2),size(b_int,2));
end  

% region grid
r1 = [min(f_x1), max(f_x1)];
r2 = [min(f_x2), max(f_x2)];
r3 = 1.1*max(max(b_int));

% plot
figure; hold on;
contourf(f_x1,f_x2,b_int.',20);

plot3(r1, r2, ones(2,2)*r3, 'k', 'LineWidth', 2);
plot3(-r1, r2, ones(2,2)*r3, 'k', 'LineWidth', 2);
plot3(r1/2, -r2, ones(2,2)*r3, 'k', 'LineWidth', 2);
plot3(-r1, r2/2, ones(2,2)*r3, 'k', 'LineWidth', 2);
plot3(zeros(2,1), r2, ones(2,2)*r3, 'k', 'LineWidth', 2);
plot3(r1, zeros(2,1), ones(2,2)*r3, 'k', 'LineWidth', 2);
hold off; axis tight; colorbar('EastOutside'); grid on; grid minor;
%caxis( [0, sum(sum(abs(bispec).^2))/numel(bispec)] );



% 
% sum(sum(abs(bispec).^2))/numel(bispec)

% if exist('Sigma', 'var')
%     caxis([0 Sigma^3])
% end


