function viscumul3(cumul, Sigma ,tau_x1, tau_x2 )
% VISCUMUL3  Visualization of the third order cumulant
%  viscumul3(cumul, Sigma ,tau_x1, tau_x2 )
%  INPUT 
%      cumul         - third order cumulant
%      Sigma         - variance of the signal for color limits (optional)
%     tau_x1, tau_x2 - min/max of delay axes (optional) 

%  Rev 1.1    Jan. 7, 2009,  Dmitriy Shutin  <dshutin@tugraz.at>
%  Rev 1.2    Jan. 13, 2009, Daniel Arnitz (partial redesign)

if nargin<1
    error('Not enough input arguments');
end

% interpolation for smoother results
c_int=interpn(cumul,2,'cubic'); 

% axes
if nargin<3
    [n,m]=size(cumul);
    tau_x1=linspace(-n/2,n/2,size(c_int,1))';
    tau_x2=linspace(-m/2,m/2,size(c_int,2))';
else
    tau_x1=linspace(min(tau_x1),max(tau_x1),size(c_int,1));
    tau_x2=linspace(min(tau_x2),max(tau_x2),size(c_int,2));
end

% region grid
r1 = [min(tau_x1), max(tau_x1)];
r2 = [min(tau_x2), max(tau_x2)];
r3 = 1.1*max(max(c_int));

% plot
figure; hold on;
contourf(tau_x1,tau_x2,c_int.',20);
plot3(r1, r2, ones(2,2)*r3, 'k', 'LineWidth', 2);
plot3(zeros(2,1), r2, ones(2,2)*r3, 'k', 'LineWidth', 2);
plot3(r1, zeros(2,1), ones(2,2)*r3, 'k', 'LineWidth', 2);
hold off; grid on; grid minor; xlim(r1); ylim(r2); colorbar('EastOutside'); 
% caxis( sum(sum(abs(cumul).^2)) * [-1.1, 1.1] );
% if exist('Sigma', 'var')
%     caxis([-Sigma.^1.5 Sigma^1.5])
% end


