function [h,q,q_unsrt]=vkernels2(x,y,sysmem);
%VKERNELS2	Second-order Volterra system identification
% [h, q, q_unsrt] = VKERNELS2 (x, y, sysmem);
% INPUT 
%        x - input of a system (a column vector)
%        y - output of a system (a column vector)
%   sysmem - assumed system's memory (in samples)
% OUTPUT
%        h - estimated IR of the linear part
%        q - estimated IR of the quadratic part
%  q_unsrt - lower triangular part of  matrix q (column orientation). 
%	    

%  Rev 1.0    Oct. 08, 2001,  Dmitriy Shutin  <dshutin@inw.tugraz.at>
%  Rev 1.1    Oct. 24, 2002,  Algorithm corrections

% Parameter checks ------------------------------------------------
if (exist('x') ~= 1  | exist('y') ~= 1)
   error('both x and y must be specified')
end
x=x(:);
y=y(:);
if (size(x) ~= size(y))
   error('x and y must have the same dimensions')
end

nsamp = size(x,1);
x=[zeros(sysmem-1,1);x];
for l=1:nsamp
	Y(l,1)=y(l);
    x_taps=x(l+sysmem-1:-1:l);
	x_corr=x_taps*x_taps';
	x_temp=[];
	for k=1:sysmem
		x_temp=[x_temp, x_corr(k,1:k)];
	end
    A(l,:)=[x_taps', x_temp];
end
disp('Matrix COND=')
cond(A)
HQ=pinv(A)*Y;
h=HQ(1:sysmem);
q_unsrt=HQ(sysmem+1:end);
q_temp=q_unsrt;
for l=1:sysmem
	q(l,1:l)=q_temp(1:l)';
	q(1:l,l)=q_temp(1:l);
    q_temp(1:l)=[];
end

