function [y]=vkernels2_o(x,h,q_unsrt,sysmem);
%VKERNEL2_O	Calculates the output of Second-order Volterra System 
%	[y] = VKERNELS2_O(x,h,q, sysmem);
%  INPUT
%	   x - input to the Volterra system ( a column-vector )
%	   h - Linear Volterra kernel ( a column-vector )
%	   q - Quadratic Volterra kernel ( a column-vector produced by VKERNELS2 ).
%          If parameter is omitted, then only the linear part in h is used.  
% sysmem - memory length in samples. (optional. by default the length of h is used)    
%  OUTPUT
%	  y - output of the Volterra model (a column vector) 

%  Rev. 1.0    Oct. 08, 2002     Shutin Dmitriy <dshutin@inw.tugraz.at>

% Parameter Checks ------------------------------------------------
if nargin<1
    y=[];
end    
if nargin<2
    y=zeros(size(x));
end
if nargin<4
    sysmem=length(h);
else
    h=h(:);
    h(sysmem+1:end)=[];
end
if nargin<3
    q_unsrt=zeros( length(h)*(length(h)+1)/2 , 1 );
end

q_unsrt=q_unsrt(:);
x=x(:);
nsamp = size(x,1);
x=[zeros(sysmem-1,1);x];
for l=1:nsamp
    x_taps=x(l+sysmem-1:-1:l);
	x_corr=x_taps*x_taps';
	x_temp=[];
	for k=1:sysmem
		x_temp=[x_temp, x_corr(k,1:k)];
	end
    A(l,:)=[x_taps', x_temp];
end
y=A*[h; q_unsrt];
