function [y]=vkernels_o(x,Vmodel);
%VKERNELS_O	Second-order Volterra system output 
% [y] = VKERNELS_O (x, Vmodel);
% INPUT 
%        x - input of a system (a column vector)
%   Vmodel.* - structure containing the trained model
%        *.h - vector of kernel coefficients (symmetric kernel)
%        *.M - model memory ( a vector )
%        *.N - nonlinearity order 
% OUTPUT
%        y - system output


%  Rev 1.0    Dec. 08, 2003,  Dmitriy Shutin  <dshutin@inw.tugraz.at>
%                             doesn't work yet for complex signals 

% Parameter checks ------------------------------------------------

if (exist('x') ~= 1 )
   error('Input vector x must be specified')
end
x=x(:);

% order of nonlinearity
N=Vmodel.P;
% model memory
M=Vmodel.M;
% kernel coefficients
h=Vmodel.h;


% computing required matrices  Ah=y -------------------------------
nsamp = size(x,1);

% data matrix
A=[];
for k=1:N
    X=[zeros( M(k)-1,1) ; x ];
    [R, Ind{k}]=constr_mat(X,k,M(k));
    A=[A, R];
end  
% accounting for a DC
A=[ones(size(A,1),1),A];
  
  
% Computing the output 
y=A*h;




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Construction of the data matrix 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [R,Ind]=constr_mat(x,N,mem)
% construction of data matrix A for LS solving for kernel coeffficients 
%   x - input signal
%   N - nonlinearity order
% mem - memory length
 
% constructing the index vector 
% Only real inputs are supported
if isreal(x) | 1
    % computing indices ( symmetric kernel)
    [Ind]=create_ind(mem,N,1);
else
    % computing indices ( a-symmetric kernel (complex), full permutations)
    ind=[1:mem];
    Ind=ind;
    for k=2:N
        Ind=combvec(ind,Ind);
    end
    Ind=Ind';
end

X = buffer(x, mem, mem-1,'nodelay');
[mX]=size(X,2);
R=[];
for k=1:mX
    d=X(end:-1:1,k);
    R=[R; prod( d(Ind),2 )'];
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%         Constructing index for real signals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [Out]=create_ind(mem,N,stInd)
%  recurrent index computation using kernel symmetry 
%   mem - memory length
%     N - nonlinearity order
% stInd - start index

%  The idea is based on the reccurent formalisation of such loop structures 
%   for i=1:N
%      for j=i:N
%        for k=j:N 
%            ...  

Out=[];

if N==1
    Out=[stInd:mem]';
    return
else
    for k=stInd:mem
        [out]=create_ind(mem,N-1,k);
        Add=[k*ones(size(out,1),1), out ];
        Out=[Out; Add];
    end
end
